import { PipeTransform, Pipe } from '@angular/core';
import { of, Observable } from 'rxjs';
import { NGXLogger } from 'ngx-logger';
import { HttpClient } from '@angular/common/http';
import { take, map, catchError, switchMap, tap } from 'rxjs/operators';

export interface ImagePipeParameter {
  path?: string;
  validation?: boolean;
  default?: string;
}

@Pipe({ name: 'ucapUiImaage' })
export class ImagePipe implements PipeTransform {
  constructor(private httpClient: HttpClient, private logger: NGXLogger) {}

  transform(
    base: string,
    params?: ImagePipeParameter
  ): Observable<string | ArrayBuffer> {
    params = !!params ? params : {};
    params.validation = !!params.validation ? params.validation : true;

    if (params.validation) {
      if (
        !base ||
        '' === base.trim() ||
        !params.path ||
        '' === params.path.trim()
      ) {
        return of(params.default);
      }
    }

    const imageUrl = `${base}${params.path}`;

    return new Observable<string | ArrayBuffer>(subscriber => {
      subscriber.next(params.default);

      this.httpClient
        .get(imageUrl, { responseType: 'blob' })
        .pipe(
          take(1),
          tap(blob => {
            const reader = new FileReader();
            reader.onloadend = ev => {
              subscriber.next(reader.result);
            };
            reader.readAsDataURL(blob);
          }),
          catchError(err => {
            this.logger.error(err);
            return params.default;
          })
        )
        .subscribe();
    });

    return this.httpClient.get(imageUrl, { responseType: 'blob' }).pipe(
      take(1),
      switchMap(blob => {
        return new Observable<string | ArrayBuffer>(subscriber => {
          const reader = new FileReader();
          reader.onloadend = ev => {
            subscriber.next(reader.result);
          };
          reader.readAsDataURL(blob);
        });
      }),
      catchError(err => {
        this.logger.error(err);
        return params.default;
      })
    );
  }
}
